pub struct HttpClient { /* private fields */ }Implementations
Sourceimpl HttpClient
impl HttpClient
pub fn new() -> Self
Sourcepub async fn send(self, request: HttpRequest) -> Result<HttpResponse>
pub async fn send(self, request: HttpRequest) -> Result<HttpResponse>
Sends an HTTP request to the server, automatically selecting the appropriate protocol and transport.
ALPN is used to determine whether to use HTTP/2 or HTTP/1.1 for the request.