pub struct HttpClientConfig {
pub tls_config: ClientConfig,
}Fields
tls_config: ClientConfigImplementations
Sourceimpl HttpClientConfig
impl HttpClientConfig
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new instance with a default set of trusted root CAs.
By default, the client trusts the system native root certs in addition to Mozilla root certificates provided by the
webpki_roots crate.