pub struct HttpServer { /* private fields */ }Implementations
Sourceimpl HttpServer
impl HttpServer
pub fn new(config: HttpServerConfig) -> Self
Sourcepub fn route<T, Fut>(self, path: impl Into<String>, callback: T) -> Selfwhere
T: Fn(HttpRequest) -> Fut + Send + Sync + 'static,
Fut: Future<Output = HttpResponse> + Send + 'static,
pub fn route<T, Fut>(self, path: impl Into<String>, callback: T) -> Selfwhere
T: Fn(HttpRequest) -> Fut + Send + Sync + 'static,
Fut: Future<Output = HttpResponse> + Send + 'static,
Registers a route with a path, associating it with a handler callback.
Sourcepub async fn run(self)
pub async fn run(self)
Run the HTTP server and begins listening for incoming TCP connections (optionally over TLS).
This method binds to the configured host address and enters a loop to accept new TCP connections. It also listens for system termination signals (SIGINT, SIGTERM) to gracefully shut down the server.