HttpRequestBuilder

Struct HttpRequestBuilder 

pub struct HttpRequestBuilder<State> { /* private fields */ }

Implementations

Source

impl HttpRequestBuilder<SetMethod>

pub fn get(self, uri: impl Into<String>) -> HttpRequestBuilder<Final>

Sets the HTTP method to GET and assigns the request URI.

pub fn post(self, uri: impl Into<String>) -> HttpRequestBuilder<Final>

Sets the HTTP method to POST and assigns the request URI.

pub fn put(self, uri: impl Into<String>) -> HttpRequestBuilder<Final>

Sets the HTTP method to PUT and assigns the request URI.

pub fn patch(self, uri: impl Into<String>) -> HttpRequestBuilder<Final>

Sets the HTTP method to PATCH and assigns the request URI.

pub fn delete(self, uri: impl Into<String>) -> HttpRequestBuilder<Final>

Sets the HTTP method to DELETE and assigns the request URI.

pub fn options(self, uri: impl Into<String>) -> HttpRequestBuilder<Final>

Sets the HTTP method to OPTIONS and assigns the request URI.

pub fn head(self, uri: impl Into<String>) -> HttpRequestBuilder<Final>

Sets the HTTP method to HEAD and assigns the request URI.

pub fn connect(self, uri: impl Into<String>) -> HttpRequestBuilder<Final>

Sets the HTTP method to CONNECT and assigns the request URI.

pub fn trace(self, uri: impl Into<String>) -> HttpRequestBuilder<Final>

Sets the HTTP method to TRACE and assigns the request URI.

Source

impl HttpRequestBuilder<Final>

pub fn body_empty(self) -> Result<HttpRequest>

Finish the builder and the create the request with an empty body.

pub fn body_boxed(self, body: BoxBody<Bytes, Error>) -> Result<HttpRequest>

Finish the builder and the create the request with a boxed body.

Used for moving a body from another request or response.

pub fn body_bytes(self, body: impl Into<Bytes>) -> Result<HttpRequest>

Finish the builder and the create the request with a body of bytes in memory.

pub fn body_stream<S>(self, stream: S) -> Result<HttpRequest>
where S: Stream<Item = Result<Bytes, Error>> + Send + Sync + 'static,

Finish the builder and the create the request with a body of bytes as a stream.

pub fn header(self, key: impl Into<String>, value: impl Into<String>) -> Self

Add a header to the request.

pub fn headers(self, headers: &HeaderMap<HeaderValue>) -> Self

Copy headers from another request or response.