HttpResponseBuilder

Struct HttpResponseBuilder 

pub struct HttpResponseBuilder<State> { /* private fields */ }

Implementations

Source

impl HttpResponseBuilder<SetStatus>

pub fn status(self, status: u16) -> HttpResponseBuilder<Final>

Source

impl HttpResponseBuilder<Final>

pub fn body_empty(self) -> Result<HttpResponse>

Finish the builder and the create the response with an empty body.

pub fn body_boxed(self, body: BoxBody<Bytes, Error>) -> Result<HttpResponse>

Finish the builder and the create the response with a boxed body.

Used for moving a body from another request or response.

pub fn body_bytes(self, body: impl Into<Bytes>) -> Result<HttpResponse>

Finish the builder and the create the response with a body of bytes in memory.

pub fn body_stream<S>(self, stream: S) -> Result<HttpResponse>
where S: Stream<Item = Result<Bytes, Error>> + Send + Sync + 'static,

Finish the builder and the create the response with a body of bytes as a stream.

pub fn header(self, key: impl Into<String>, value: impl Into<String>) -> Self

Add a header to the response.

pub fn headers(self, headers: &HeaderMap<HeaderValue>) -> Self

Copy headers from another request or response.